-------------------------------------------------
-- Shockwave3DBatchExport
--
--  Created by Dennis Roche 
--   godennis@gmail.com
--
--  Liquid Animation  2007
--
-------------------------------------------------
	

global gScriptRootDir = getDir #scripts + "\\LiquidAnimation\\"
global gSourceDir = undefined
global gExportDir = undefined
global gUsingBipFile = undefined
global gLogWindow = undefined

global ui_setup

-------------------------------------------------
-- FUNCTIONS
-------------------------------------------------


/*
 * function: changeExportSettings
 *  prompts user to change shockwave3d settings
 */
function changeExportSettings sourceDir =
(
	-- reset everything
	resetMaxFile(#noPrompt)
	
	-- tmp
	local tmpFile = (sourceDir+"\\\\settings.w3d")

	-- export dummy w3d file to set export settings 
	exportFile tmpFile using:SW3D_Exp	
	deleteFile tmpFile
)


/*
 * function: startBatchExport
 *  resets the scene, sets w3d export settings
 *   and exports all files in search directory
 *
 */
function startBatchExport sourceDir exportDir bipFile =
(
	
	gLogWindow = newScript()
	
	-- start log
	format "-------------------------------------------\n" localTime to:gLogWindow
	format "-- Start Batch - %\n" localTime to:gLogWindow
	format "-------------------------------------------\n" localTime to:gLogWindow
	
	-- reset everything
	resetMaxFile(#noPrompt)

	-- get files to export
	maxFiles = getFilesInDirectory(sourceDir)

	format "Found % files in %\n" maxFiles.count (unescapePath sourceDir) to:gLogWindow
	
	local count = 0
	
	-- export assets
	for f in maxFiles while (keyboard.escPressed != true) do 
	(
		
		-- inc. counter
		count = count + 1
		
		-- open file
		local loadOk = loadMaxFile f useFileUnits:true quiet:true
		local w3dFile = (exportDir+"\\\\"+(getFilenameFile f)+".w3d")
		
		if loadOk then (	
			format "[% of %] Exporting % \n" count maxFiles.count (unescapePath w3dFile) to:gLogWindow
			-- 
			exportShockwave bipFile w3dFile
		)
	)
	
	-- done
	batchExportCompleted()

)


/*
 * function: batchExportCompleted
 *
 */
function batchExportCompleted =
(
	-- start log
	format "-------------------------------------------\n" localTime to:gLogWindow
	format "-- Batch Completed - %\n" localTime to:gLogWindow
	format "-------------------------------------------\n" localTime to:gLogWindow
	-- reset everything
	resetMaxFile(#noPrompt)
)


/*
 * function: exportShockwave
 *  exports shockwave file
 */
function exportShockwave bipFile w3dFile =
(
	local bipNode = $bip01
	
	-- set file frameRate to 15
	frameRate = 15.0
	
	-- change into motion mode
	max motion mode
	if bipNode.controller.figureMode == true then (
		messageBox "Please Exit Figure Mode" title:"Shockwave3D Export"
	) else (
		disablesceneredraw()
		biped.LoadBipFile bipNode.controller bipFile
		enablesceneredraw()
		max views redraw
	)
	
	-- export file
	exportFile w3dFile #noPrompt using:"SW3D_Exp"		
	
)


/*
 * function: getSettings
 *  get settings from the ini file
 */
function getSettings =
(
	-- read the *.ini file
	local file = gScriptRootDir+"Shockwave3DBatchExport.ini"
	local key = (getIniSetting file "PREFERENCES")

	-- reads the key/value pairs
	for i in key do (
		local v = getIniSetting file "PREFERENCES" i
		case i of (
			"LastSourceDir":
				gSourceDir = (v as string)
			"LastExportDir":
				gExportDir = (v as string)
			"LastBIPFile":
				gUsingBipFile = (v as string)
		)
	)
)



/*
 * function: saveSettings
 *  saves settings to an ini file
 */
function saveSettings =
(
	-- create file
	local file = gScriptRootDir+"Shockwave3DBatchExport.ini"
	local fs = createFile (file)
	-- write library data to file
	if fs != undefined then	(
		-- header
		format "; Shockwave3DBatchExport\n" to:fs
		format "[PREFERENCES]\n" to:fs
		format "%=%\n" "LastSourceDir" gSourceDir to:fs
		format "%=%\n" "LastExportDir" gExportDir to:fs
		format "%=%\n" "LastBIPFile" gUsingBipFile to:fs
 	)
	-- close filestream
	flush fs
	close fs
)


/*
 * function: getFilesInDirectory
 *  get *.max files from directory
 */
function getFilesInDirectory searchDir = 
(	
	-- look in subdirectories
	local subDirectories = getDirectories (searchDir+"*")
	for d in subDirectories do (
		join subDirectories (GetDirectories (d+"*"))
	)
	
	local maxFiles = #()	
	for d in subDirectories do 
	(
		-- expecting only 1 file per directory
		local file = (getFiles (d + "*.max"))[1]
		if file != undefined then (
			append maxFiles file
		)
	)

	return maxFiles
)


/*
 * function: escapePath
 * 
 */
function escapePath pathIn =
(
	tokens = filterString pathIn "\\"
	pathOut = tokens[1]
	for i = 2 to tokens.count do
	(
		pathOut = pathOut + "\\\\" + tokens[i]
	)
	return pathOut
)


/*
 * function: unescapePath
 * 
 */
function unescapePath pathIn =
(
	tokens = filterString pathIn "\\"
	pathOut = tokens[1]
	for i = 2 to tokens.count do
	(
		pathOut = pathOut + "\\" + tokens[i]
	)
	return pathOut
)



-------------------------------------------------
-- UI
-------------------------------------------------


/*
 * Create Point Cache Rollout
 *
 */
rollout ui_setup "Setup"
(
	label lbl_sourceDirectory "Source Directory" pos:[6,5]
	edittext txt_sourceDirectory "" pos:[2,20] fieldWidth:180 height:18 readOnly:true alignment:#right
	button btn_changeSourceDirectory "..." pos:[190,20] height:18 toolTip:"Change Source Directory"
		
	label lbl_exportDirectory "Export Directory" pos:[6,45]
	edittext txt_exportDirectory "" pos:[2,60] fieldWidth:180 height:18 readOnly:true alignment:#right
	button btn_changeExportDirectory "..." pos:[190,60] height:18 toolTip:"Change Export Directory"
	
	label lbl_usingBipFile "Use BIP File" pos:[6,85]
	edittext txt_usingBipFile "" pos:[2,100] fieldWidth:180 height:18 readOnly:true alignment:#right
	button btn_selectBipFile "..." pos:[190,100] height:18 toolTip:"Change Bip File"
	
	button btn_changeExportSettings "Change Export Settings" pos:[6,140] height:25 width:210
	button btn_startBatchProcess "Start Batch" pos:[6,170] height:40 width:210 enabled:false
	
	/*
	 * Functions
	 */
	function enableUI value = 
	(
		btn_changeExportSettings.enabled = value
		btn_startBatchProcess.enabled = value
	)
	
	
	function updateUI = 
	(
		-- display path
		if gSourceDir != undefined then (
			txt_sourceDirectory.text = gSourceDir
		)
		-- display path
		if gExportDir != undefined then (
			txt_exportDirectory.text = gExportDir
		)
		-- check file
		if gUsingBipFile != undefined then (
			if getFileSize gUsingBipFile > 0 then
			(
				txt_usingBipFile.text = gUsingBipFile
				enableUI true
			) else (
				txt_usingBipFile.text = ""
			)
		)
	)
	
	
	/*
	 * Events
	 */
	 
	on ui_setup open do 
	(
		-- get settings
		getSettings()
		updateUI()
	)
	 
	
	on btn_changeSourceDirectory pressed do 
	( 
		-- change source directory
		savePath = getSavePath caption:"Set Source Directory" initialDir:gSourceDir
		if savePath != undefined or savePath != "" then (
			-- ok
			gSourceDir = savePath
			updateUI()
		)
	)
	
	
	on btn_changeExportDirectory pressed do 
	( 
		-- change working directory
		savePath = getSavePath caption:"Set Export Directory" initialDir:gExportDir
		if savePath != undefined or savePath != "" then (
			-- ok
			gExportDir = savePath
			updateUI()
		)
	)
	
	
	on btn_selectBipFile pressed do 
	(
		-- using bip file
		filePath = getOpenFileName caption:"Select BIP File" initialDir:(getFilenamePath gUsingBipFile) types:"BIP(*.bip)|*.bip"

		if filePath != undefined and filePath != "" then (
			gUsingBipFile = filePath
			
		)
		updateUI()
	)
	
	
	on btn_changeExportSettings pressed do
	(
		changeExportSettings (escapePath gSourceDir)
	)
	
	
	on btn_startBatchProcess pressed do 
	(
		startBatchExport (escapePath gSourceDir) (escapePath gExportDir) (escapePath gUsingBipFile)  
	)

)


/*
 * About Point Cache Snapshot
 *
 */
rollout ui_aboutShockwave3DBatchExport "About"
(
	-- who made this?
	label lbl_about0 "Shockwave3D Batch Export v0.4" align:#center
	label lbl_about1 "Written by Dennis Roche" align:#center
	label lbl_about2 ""
	label lbl_about3 "Liquid Animation  2007" align:#center
)


-------------------------------------------------
-- MAIN
-------------------------------------------------
	
	
/*
 * Main Rollout
 *  main dialog rollout
 *
 */
rollout ui_Shockwave3DBatchExportMain "Shockwave3D Export"
(
	
	subrollout ui_panel width:235 height:350 pos:[2,0]
		
	/*
	 * Events
	 */
    on ui_Shockwave3DBatchExportMain open do (
	    -- add rollouts 
	    addSubRollout ui_panel ui_setup
	    addSubRollout ui_panel ui_aboutShockwave3DBatchExport rolledUp:true
    )
    
     on ui_Shockwave3DBatchExportMain close do (
	    -- remove rollouts 
	    removeSubRollout ui_panel ui_setup
	    removeSubRollout ui_panel ui_aboutShockwave3DBatchExport
	   
	   	-- save settings
		saveSettings()	
    )
    
)


createDialog ui_Shockwave3DBatchExportMain width:235 height:350 modal:false style:#(#style_titlebar, #style_sysmenu, #style_minimizebox)


-------------------------------------------------
-- END
-------------------------------------------------